/* Copyright (C) 2012 Andre Noll <maan@tuebingen.mpg.de>, see file COPYING. */

/** \file mix.h Mixer API for para_mixer. */

/**
 * Opaque structure which corresponds to an instance of a mixer.
 *
 * A pointer to a structure of this type is returned by ->open().  This pointer
 * must be passed to most other methods of \ref struct mixer.
 */
struct mixer_handle;

/**
 * Operations provided by each mixer plugin.
 *
 * Each mixer plugin must define a non-static instance of this structure, with
 * all pointers initialized to non-NULL values. No other symbols need to be
 * exported.
 */
struct mixer {
	/** Used to identify the mixer. */
	const char * const name;
	/** Return a handle that can be passed to other methods. */
	int (*open)(const char *dev, struct mixer_handle **handle);
	/** Returns a string of all valid mixer channels. */
	char *(*get_channels)(struct mixer_handle *handle);
	/** Select the channel for subsequent get/set operations. */
	int (*set_channel)(struct mixer_handle *handle,
		const char *mixer_channel);
	/** Return the (normalized) current value of the selected channel. */
	int (*get)(struct mixer_handle *handle);
	/** Change the value of the selected channel. */
	int (*set)(struct mixer_handle *handle, int val);
	/** Free all resources associated with the given handle. */
	void (*close)(struct mixer_handle **handle);
};

/** Declared even if unsupported because it does not hurt and avoids ifdefs. */
extern const struct mixer alsa_mixer, oss_mixer;
